@@ -1,7 +1,7 @@
 from wagtail.admin.edit_handlers import StreamFieldPanel
 
 from webspace.cms.amp.mixins import AmpMixin
-from webspace.cms.bakery.abstract import WagtailPageBakeryModel
+from webspace.bakery.abstract import WagtailPageBakeryModel
 from webspace.cms import constants
 from webspace.loader import get_model
 from webspace.cms.forms.abstract import FormMixin
