@@ -147,11 +147,16 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         default='',
         help_text="Text qui apparait en haut des articles en lien"
     )
+    button_view_all_articles = models.CharField(default='', blank=True, max_length=100)
+
     related_portfolios_text = RichTextField(
         blank=True,
         default='',
         help_text="Text qui apparait en haut des portfolios en lien"
     )
+    button_view_all_portfolios = models.CharField(default='', blank=True, max_length=100)
+
+
 
     multi_header = models.BooleanField(
         default=True,
@@ -175,6 +180,12 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         FieldPanel('summary_text'),
         FieldPanel('search_text'),
         FieldPanel('related_articles_text'),
+        FieldPanel('button_view_all_articles')
+    ]
+
+    portfolio_panels = [
+        FieldPanel('related_portfolios_text'),
+        FieldPanel('button_view_all_portfolios')
     ]
 
     socials_panels = [
@@ -226,6 +237,7 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         ObjectList(organization_panels, heading='Organization'),
         ObjectList(socials_panels, heading='Socials'),
         ObjectList(blog_panels, heading='Articles'),
+        ObjectList(portfolio_panels, heading='Portfolio'),
         ObjectList(multi_panels, heading='Multilingue'),
     ])
 
